* Franchino, Fabio, Mark A. Kayser, and Christopher Wratil (2021) `Electoral Competitiveness and Responsiveness: Rational Anticipation in the EU Council' Journal of European Public Policy.

* STEP 2.	Merging the variable Expected government duration into the deu dataset

* Import deu_positions 
import excel "deu_positions (I-III).xlsx", sheet("Sheet1") cellrange(A1:P5077) firstrow clear
drop F*

* For matching with the excel file
gen obs=_n
format DateofProposal %tdDDmonCCYY

* Merge with FKW3
merge m:m Country DateofProposal using FKW3.dta, nogen
sort Country DateofProposal

* Merge with Cyprus_Malta_Poland
merge m:m Country DateofProposal using Cyprus_Malta_Poland.dta, nogen
sort Country DateofProposal
replace FKW3expdurat = max_govdurat if Country=="cy" | Country=="mt" /* set expdurat to max_govdurat for these countries */
replace FKW3expdurat = max_govdurat if Country=="pl" & edate>date("09oct2011","DMY") /* set expdurat to max_govdurat for the Polish years - we have no CMP data */
replace FKW3expdurat_sem = . if Country=="mt" /* drop estimates for 1996 & 1998 Maltese govts - they are too early and should not be carried forward */

* Expand edate, sdate and enddate
replace edate=edate[_n-1] if Country==Country[_n-1] & edate==.
replace sdate=sdate[_n-1] if Country==Country[_n-1] & sdate==.
replace enddate=enddate[_n-1] if Country==Country[_n-1] & enddate==.
order edate, before(sdate)
order DateofProposal, after(sdate)

* Generate next_edate (date of next election)
sort Country edate sdate
gen next_edate=edate[_n+1] if Country==Country[_n+1] & edate<edate[_n+1]
format next_edate %tdDDmonCCYY
label variable next_edate "date of next election"
order next_edate, after(edate)
forvalues i = 1(1)150 {
replace next_edate=next_edate[_n+1] if Country==Country[_n+1] & next_edate==.
 }
do "add last election dates"

* Add CIEP
do "add CIEP"
order CIEP, after(next_edate)

* Compute duration measures
sort Country DateofProposal
replace FKW3expdurat=FKW3expdurat[_n-1]-(DateofProposal-DateofProposal[_n-1]) if Country==Country[_n-1] & FKW3expdurat==. & DateofProposal<=enddate
replace FKW3expdurat_sem=FKW3expdurat_sem[_n-1] if Country==Country[_n-1] & FKW3expdurat_sem==. & DateofProposal<=enddate
replace FKW3expdurat_sem = . if Country=="pl" & edate>date("09oct2011","DMY") /* we set the "time to CIEP" for these obs (becasue of missing CMP), so _sem should be missing */

replace max_govdurat=max_govdurat[_n-1]-(DateofProposal-DateofProposal[_n-1]) if Country==Country[_n-1] & max_govdurat==. & DateofProposal<=enddate
replace FKW3expdurat = max_govdurat if FKW3expdurat  > max_govdurat & FKW3expdurat!=. /* trim FKW3expdurat to max_govdurat if higher */

**  Compute duration measures for caretaker governments
* caretaker governments omitted from survival model
replace FKW3expdurat=(edate+(365*CIEP))-DateofProposal if DateofProposal<next_edate & caretaker==1 & FKW3expdurat==. /* set to max wrt edate for caretakers with DoP preceding next election */
replace FKW3expdurat=(next_edate+(365*CIEP))-DateofProposal if DateofProposal>=next_edate & caretaker==1 & FKW3expdurat==. /* set to max wrt next_edate for caretakers with DoP after next election */
* estimated governments that have become caretakers
replace FKW3expdurat=(next_edate+(365*CIEP))-DateofProposal if DateofProposal>=next_edate & caretaker==1 & FKW3expdurat!=. /* set to max wrt next_edate for caretakers with DoP after next election */
replace FKW3expdurat_sem= . if DateofProposal>=next_edate & caretaker==1 & FKW3expdurat!=.

* Delete early obs
gen cutoff = date("01jan1995", "DMY")
drop if DateofProposal<cutoff
drop cutoff

drop if obs==.
sort obs DateofProposal

count if FKW3expdurat==.  /* check - should be zero */

* copy FKW3variables into the deu_positions (I-III).xlsx